# Models

::: lume_model.base
    options:
        members:
            - LUMEBaseModel

::: lume_model.models.torch_model
    options:
        members:
            - TorchModel

::: lume_model.models.torch_module
    options:
        members:
            - TorchModule
